@@ -12,11 +12,12 @@ from jass.game.rule_schieber import RuleSchieber
 
 class AgentRandomSchieber (Agent):
     """
-    Randomly select actions for the match of jass (Schieber)
+    Randomly select actions for the game of jass (Schieber)
     """
     def __init__(self):
         # log actions
         self._logger = logging.getLogger(__name__)
+        # self._logger.setLevel(logging.INFO)
         # Use rule object to determine valid actions
         self._rule = RuleSchieber()
         # init random number generator
@@ -26,7 +27,7 @@ class AgentRandomSchieber (Agent):
         """
         Select trump randomly. Pushing is selected with probability 0.5 if possible.
         Args:
-            obs: the current match
+            obs: the current game
         Returns:
             trump action
         """
@@ -45,14 +46,14 @@ class AgentRandomSchieber (Agent):
         """
         Select randomly a card from the valid cards
         Args:
-            obs: The observation of the jass match for the current player
+            obs: The observation of the jass game for the current player
         Returns:
             card to play
         """
+        self._logger.info('Card request')
         # cards are one hot encoded
         valid_cards = self._rule.get_valid_cards_from_obs(obs)
         # convert to list and draw a value
         card = self._rng.choice(np.flatnonzero(valid_cards))
-        self._logger.debug('Played card: {}'.format(card_strings[card]))
+        self._logger.info('Played card: {}'.format(card_strings[card]))
         return card
-
