@@ -4,5 +4,5 @@
 #
 
 # new base package for main classes
-name='match' \
-     ''
\ No newline at end of file
+name = 'game' \
+     ''
