@@ -11,15 +11,15 @@ from jass.game.game_state import GameState
 
 class GameLogEntry:
     """
-    Class to capture the information contained in match logs that are saved from real and simulated games
-    and contain the match, the date and information about the players.
+    Class to capture the information contained in game logs that are saved from real and simulated games
+    and contain the game, the date and information about the players.
     """
     def __init__(self, game: GameState, date: datetime = None, player_ids: List[int] = None):
         """
         Game entry
         Args:
-            game: a match state of a completed match
-            date: the data when the match was played
+            game: a game state of a completed game
+            date: the date when the game was played
             player_ids: information about the players
         """
         self.game = game
@@ -27,7 +27,7 @@ class GameLogEntry:
         self.player_ids = player_ids
 
     def __eq__(self, other):
-        return self.game == other.match and self.date == other.date and self.player_ids == other.player_ids
+        return self.game == other.game and self.date == other.date and self.player_ids == other.player_ids
 
     def to_json(self) -> dict:
         """
@@ -42,6 +42,6 @@ class GameLogEntry:
 
     @classmethod
     def from_json(cls, data):
-        return GameLogEntry(game=GameState.from_json(data['match']),
+        return GameLogEntry(game=GameState.from_json(data['game']),
                             date=datetime.strptime(data['date'], DATE_FORMAT),
                             player_ids=data['player_ids'])
